==> Full-Month-InfiDux-ERP-100_202106.zip: classes/CommonFunctions.php <==
<?php
include_once DOCUMENT_ROOT_CLASS.'lib/Session.php';

class CommonFunctions
{   
    // Db Property
    //private $db;
    // Db __construct Method
    public function __construct()
    {
        $this->db = new Database();
    }
    //Get Data common function for multiple use
    public function getData($table,$con = null){
        $sql = "SELECT * FROM $table ";
        if(!empty($con)){
            $sql .= $con;
        }
        //$sql .= " ORDER BY id DESC ";
        $stmt = $this->db->pdo->prepare($sql);
        $stmt->execute();
        return $stmt->fetchAll();
    }
    public function getRowData($table,$con = null){
        $sql = "SELECT * FROM $table ";
        if(!empty($con)){
            $sql .= $con;
        }
        //$sql .= " ORDER BY id DESC ";
        $stmt = $this->db->pdo->prepare($sql);
        $stmt->execute();
        return $stmt->fetch();
    }
    public function updateData($table,$con,$update_data,$redirect){
        try {
            $sql = "UPDATE ".$table." SET ".$update_data." ".$con;
            $this->db->pdo->exec($sql);
            echo "<script>location.href='".$redirect."';</script>";
            Session::set('msg', '<div class="alert alert-success alert-dismissible mt-3" id="flash-msg">
              <a href="#" class="close" data-dismiss="alert" aria-label="close">&times;</a>
              <strong>Success !</strong> Wow, Your Information updated Successfully !</div>');
        }catch(PDOException $e) {
            echo "<script>location.href='".$redirect."';</script>";
            Session::set('msg', '<div class="alert alert-danger alert-dismissible mt-3" id="flash-msg">
    <a href="#" class="close" data-dismiss="alert" aria-label="close">&times;</a>
    <strong>Error !</strong> Data not updated !</div>');
        }
    }
    public function addData($table,$adding_data,$redirect){
        try {
            $sql = "INSERT INTO ".$table." ".$adding_data;
            $this->db->pdo->exec($sql);
            echo "<script>location.href='".$redirect."';</script>";
            Session::set('msg', '<div class="alert alert-success alert-dismissible mt-3" id="flash-msg">
              <a href="#" class="close" data-dismiss="alert" aria-label="close">&times;</a>
              <strong>Success !</strong> Wow, Your Information added Successfully !</div>');
        }catch(PDOException $e) {
            echo "<script>location.href='".$redirect."';</script>";
                Session::set('msg', '<div class="alert alert-danger alert-dismissible mt-3" id="flash-msg">
    <a href="#" class="close" data-dismiss="alert" aria-label="close">&times;</a>
    <strong>Error !</strong> Data not inserted !</div>');
        }
    }
    function deleteRowData($table,$con,$update_data,$redirect){
        try {
            $sql = "UPDATE ".$table." SET ".$update_data." ".$con;
            $this->db->pdo->exec($sql);
            echo "<script>location.href='".$redirect."';</script>";
            Session::set('msg', '<div class="alert alert-success alert-dismissible mt-3" id="flash-msg">
              <a href="#" class="close" data-dismiss="alert" aria-label="close">&times;</a>
              <strong>Success !</strong> Wow, Your Information deleted Successfully !</div>');
        }catch(PDOException $e) {
            echo "<script>location.href='".$redirect."';</script>";
            Session::set('msg', '<div class="alert alert-danger alert-dismissible mt-3" id="flash-msg">
    <a href="#" class="close" data-dismiss="alert" aria-label="close">&times;</a>
    <strong>Error !</strong> Something went wrong from server side. please try again !</div>');
        }
    }
    //get columun value 
    function getName($id, $table, $field = 'name', $key = 'id', $msg = '') {
        $sql = "SELECT $field FROM $table WHERE $key = $id ";
        $stmt = $this->db->pdo->prepare($sql);
        $stmt->execute();
        $resultData = $stmt->fetch();
        return $resultData[$field];
    }
    public function getRowDataCount($table,$con = null){
        $sql = "SELECT * FROM $table ";
        if(!empty($con)){
            $sql .= $con;
        }
        //$sql .= " ORDER BY id DESC ";
        $stmt = $this->db->pdo->prepare($sql);
        $stmt->execute();
        return !empty($stmt->rowCount())?"00".$stmt->rowCount():0;      
    }
    public function getRecordCount($table,$con = null){
        $sql = "SELECT * FROM $table ";
        if(!empty($con)){
            $sql .= $con;
        }
        //$sql .= " ORDER BY id DESC ";
        $stmt = $this->db->pdo->prepare($sql);
        $stmt->execute();
        return !empty($stmt->rowCount())?$stmt->rowCount():0;      
    }
    public function getIDs($table,$field,$con = null){
        $sql = "SELECT GROUP_CONCAT($field) as ids FROM $table ";
        if(!empty($con)){
            $sql .= $con;
        }
        //$sql .= " ORDER BY id DESC ";
        $stmt = $this->db->pdo->prepare($sql);
        $stmt->execute();
        return $stmt->fetch();
    }
    public function addImportData($table,$adding_data,$redirect){   
        $sql = "INSERT INTO ".$table." ".$adding_data;
        return $this->db->pdo->exec($sql);
    }
}
?>

==> Full-Month-InfiDux-ERP-100_202107.zip: classes/CommonFunctions.php <==
<?php
include_once DOCUMENT_ROOT_CLASS.'lib/Session.php';

class CommonFunctions
{   
    // Db Property
    //private $db;
    // Db __construct Method
    public function __construct()
    {
        $this->db = new Database();
    }
    //Get Data common function for multiple use
    public function getData($table,$con = null){
        $sql = "SELECT * FROM $table ";
        if(!empty($con)){
            $sql .= $con;
        }
        //$sql .= " ORDER BY id DESC ";
        $stmt = $this->db->pdo->prepare($sql);
        $stmt->execute();
        return $stmt->fetchAll();
    }
    public function getRowData($table,$con = null){
        $sql = "SELECT * FROM $table ";
        if(!empty($con)){
            $sql .= $con;
        }
        //$sql .= " ORDER BY id DESC ";
        $stmt = $this->db->pdo->prepare($sql);
        $stmt->execute();
        return $stmt->fetch();
    }
    public function updateData($table,$con,$update_data,$redirect){
        try {
            $sql = "UPDATE ".$table." SET ".$update_data." ".$con;
            $this->db->pdo->exec($sql);
            if($redirect != ''){
                echo "<script>location.href='".$redirect."';</script>";
                Session::set('msg', '<div class="alert alert-success alert-dismissible mt-3" id="flash-msg">
                  <a href="#" class="close" data-dismiss="alert" aria-label="close">&times;</a>
                  <strong>Success !</strong> Wow, Your Information updated Successfully !</div>');
            }
        }catch(PDOException $e) {
            if($redirect != ''){
                echo "<script>location.href='".$redirect."';</script>";
                Session::set('msg', '<div class="alert alert-danger alert-dismissible mt-3" id="flash-msg">
        <a href="#" class="close" data-dismiss="alert" aria-label="close">&times;</a>
        <strong>Error !</strong> Data not updated !</div>');
            }
        }
    }
    public function addData($table,$adding_data,$redirect){
        try {
            $sql = "INSERT INTO ".$table." ".$adding_data;
            $this->db->pdo->exec($sql);
            if($redirect != ''){
                echo "<script>location.href='".$redirect."';</script>";
                Session::set('msg', '<div class="alert alert-success alert-dismissible mt-3" id="flash-msg">
                  <a href="#" class="close" data-dismiss="alert" aria-label="close">&times;</a>
                  <strong>Success !</strong> Wow, Your Information added Successfully !</div>');
            }else{
                return $this->db->pdo->lastInsertId();
            }
        }catch(PDOException $e) {
            if($redirect != ''){
                echo "<script>location.href='".$redirect."';</script>";
                Session::set('msg', '<div class="alert alert-danger alert-dismissible mt-3" id="flash-msg">
    <a href="#" class="close" data-dismiss="alert" aria-label="close">&times;</a>
    <strong>Error !</strong> Data not inserted !</div>');
            }
        }
    }
    function deleteRowData($table,$con,$update_data,$redirect){
        try {
            $sql = "UPDATE ".$table." SET ".$update_data." ".$con;
            $this->db->pdo->exec($sql);
            echo "<script>location.href='".$redirect."';</script>";
            Session::set('msg', '<div class="alert alert-success alert-dismissible mt-3" id="flash-msg">
              <a href="#" class="close" data-dismiss="alert" aria-label="close">&times;</a>
              <strong>Success !</strong> Wow, Your Information deleted Successfully !</div>');
        }catch(PDOException $e) {
            echo "<script>location.href='".$redirect."';</script>";
            Session::set('msg', '<div class="alert alert-danger alert-dismissible mt-3" id="flash-msg">
    <a href="#" class="close" data-dismiss="alert" aria-label="close">&times;</a>
    <strong>Error !</strong> Something went wrong from server side. please try again !</div>');
        }
    }
    //get columun value 
    function getName($id, $table, $field = 'name', $key = 'id', $msg = '') {
        $sql = "SELECT $field FROM $table WHERE $key = $id ";
        $stmt = $this->db->pdo->prepare($sql);
        $stmt->execute();
        $resultData = $stmt->fetch();
        return $resultData[$field];
    }
    public function getRowDataCount($table,$con = null){
        $sql = "SELECT * FROM $table ";
        if(!empty($con)){
            $sql .= $con;
        }
        //$sql .= " ORDER BY id DESC ";
        $stmt = $this->db->pdo->prepare($sql);
        $stmt->execute();
        return !empty($stmt->rowCount())?"00".$stmt->rowCount():0;      
    }
    public function getRecordCount($table,$con = null){
        $sql = "SELECT * FROM $table ";
        if(!empty($con)){
            $sql .= $con;
        }
        //$sql .= " ORDER BY id DESC ";
        $stmt = $this->db->pdo->prepare($sql);
        $stmt->execute();
        return !empty($stmt->rowCount())?$stmt->rowCount():0;      
    }
    public function getIDs($table,$field,$con = null){
        $sql = "SELECT GROUP_CONCAT($field) as ids FROM $table ";
        if(!empty($con)){
            $sql .= $con;
        }
        //$sql .= " ORDER BY id DESC ";
        $stmt = $this->db->pdo->prepare($sql);
        $stmt->execute();
        return $stmt->fetch();
    }
    public function addImportData($table,$adding_data,$redirect){   
        $sql = "INSERT INTO ".$table." ".$adding_data;
        return $this->db->pdo->exec($sql);
    }
    public function addLogData($table,$adding_data,$redirect=null){
        try {
            $sql = "INSERT INTO ".$table." ".$adding_data;
            $this->db->pdo->exec($sql);
        }catch(PDOException $e) {

        }
    }
}
?>
